@@ -4,7 +4,7 @@ f  gnc-module.scm	g  set-current-module	 
  	g  load-extension	f  
 libgnc-module	f  scm_init_sw_gnc_module_module	g  process-use-modules	 	 	g  
 sw_gnc_module	 	 	g  gnc-module-system-init	g  gnc:module-system-init	g  gnc-module-system-refresh	g  gnc:module-system-refresh	g  gnc-module-load	g  gnc:module-load	g  gnc-module-load-optional	g  gnc:module-load-optional	g  gnc-module-unload	 g  gnc:module-unload	!g  call-with-deferred-observers	"! 	#! 	$g  module-export!	%$ 	&$ 	'g  current-module	(' 	)' 	* 	+ 	, 	- 	.  	/g  gnc:module-begin-syntax	0/ 	1g  make-syntax-transformer	21 	31 	4g  macro	5g  $sc-dispatch	65 	75 	8g  any	9g  each-any	:89	;g  
-syntax-object	<g  	eval-when	=g  top	>= 	?g  ribcage	@g  dummy	Ag  form	B@A 	Cg  m-j9zhGp9XsNCKf1VEicoreC-252	DC= 	ED> 	Ff  l-j9zhGp9XsNCKf1VEicoreC-257	Gf  l-j9zhGp9XsNCKf1VEicoreC-258	HFG 	I?BEH 	J? 	Kg  x	LK 	MD 	Nf  l-j9zhGp9XsNCKf1VEicoreC-254	ON 	P?LMO 	Q>IJP 	Rg  hygiene	SR 	T;<QS 	Ug  load	V;UQS 	Wg  compile	X;WQS 	Yg  eval	Z;YQS 	[g  expand	\;[QS 	]VXZ\ 	^g  begin	_;^QS 	`g  syntax-violation	a` 	b` 	cf  -source expression failed to match any patternC 5      h     ]4	
+syntax-object	<g  	eval-when	=g  top	>= 	?g  ribcage	@g  dummy	Ag  form	B@A 	Cg  m-yajEt7DY4R@wtrsSeovowC-252	DC= 	ED> 	Ff  l-yajEt7DY4R@wtrsSeovowC-257	Gf  l-yajEt7DY4R@wtrsSeovowC-258	HFG 	I?BEH 	J? 	Kg  x	LK 	MD 	Nf  l-yajEt7DY4R@wtrsSeovowC-254	ON 	P?LMO 	Q>IJP 	Rg  hygiene	SR 	T;<QS 	Ug  load	V;UQS 	Wg  compile	X;WQS 	Yg  eval	Z;YQS 	[g  expand	\;[QS 	]VXZ\ 	^g  begin	_;^QS 	`g  syntax-violation	a` 	b` 	cf  -source expression failed to match any patternC 5      h     ]4	
 5 4
  >  "  G   4i>  "  G  4 >  "  G  iRiRiRiRi R4#&)* h   @   ] 45 6   8       g  filenamef  gnc-module.scm
 	.
